BBBB BBBB
BBBBBBBBBBBBBBBBBBBB BB BBBBBBBBBBBBB

XX XXXXXXXXXXXXXXXX XXXXXXXXXXXXX
    BB BBBBBBBBBBBBBBBBBBBBBBBBBBBBB
    
        XX XXXXXXXX XXXXXXBBB BBBBBBBBBXX gettext(u'Profile') XXXX

    
        XX XXXXXXXX XXXXXXBBB BBBBBBBBBBBBBBBBXX gettext(u'Update Profile') XXXX

    
        XX XXXXXXXX XXXXXXBBB BBBBBBBBBBBBBBBXX gettext(u'Change E-mail') XXXX

    
        XX XXXXXXXX XXXXXXBBB BBBBBBBBBBBBBBBBXX gettext(u'Sign Out') XXXX

    BBBB

    
        XX XXXXXXXXXXXXXXXXX XXXXXXXX XXXXXXBBB BBBBBBBBBBBBBBBBXX gettext(u'Sign Up') XXXX

    
        XX XXXXXXXXXXXXXXXX XXXXXXXX XXXXXXBBB BBBBBBBBBBBBBBBXX gettext(u'Sign In') XXXX

    BBBBB
XXXX
