BBBB BBBB
BBBBBBBBBBBBBBBBBBBB BB BBBBBBBBBBBBB


XXXX XXXXXXXXXXXXXXXXXX
    XXX XXXXXXXXXX XXXXXXXXX XXXXXXXXXXXXXXXXXXXXXXXX
        BB BBBBBBBBBBBBBBBBBBBBBBBBBBBBB
        XXX XXXXXXXXXXXXXXXXX
        
            XX XXXXXXXXXXXXXXXX XXXXXXBBB BBBBBBBBBXX gettext(u'Profile') XXXX
        XXXXX
        XXX XXXXXXXXXXXXXXXXX
        
            XX XXXXXXXXXXXXXXXX XXXXXXBBB BBBBBBBBBBBBBBBBXX gettext(u'Update Profile') XXXX
        XXXXX
        XXX XXXXXXXXXXXXXXXXX
        
            XX XXXXXXXXXXXXXXXX XXXXXXBBB BBBBBBBBBBBBBBBXX gettext(u'Change E-mail') XXXX
        XXXXX
        XXX XXXXXXXXXXXXXXXXX
        
            XX XXXXXXXXXXXXXXXX XXXXXXBBB BBBBBBBBBBBBBBBBXX gettext(u'Sign Out') XXXX
        XXXXX
        BBBB
        XXX XXXXXXXXXXXXXXXXX
        
            XX XXXXXXXXXXXXXXXXX XXXXXXXXXXXXXXXX XXXXXXBBB BBBBBBBBBBBBBBBBXX gettext(u'Sign Up') XXXX
        XXXXX
        XXX XXXXXXXXXXXXXXXXX
        
            XX XXXXXXXXXXXXXXXX XXXXXXXXXXXXXXXX XXXXXXBBB BBBBBBBBBBBBBBBXX gettext(u'Sign In') XXXX
        XXXXX
        BBBBB
    XXXXX
XXXXXX
