{% extends "base.html" %}
{% load static i18n %}

{% block title %}{{ block.super }} - {% block head_title %}{% endblock head_title %}{% endblock title %}


{% block content %}
<div class="container container-full">
    <div class="row">
        <div class="col-md-8 offset-md-2 col-lg-6 offset-lg-3">
        {% block inner %}{% endblock %}
        </div>
    </div>
</div>
{% endblock %}
